SET SEARCH_PATH = iqp_apprealm;

CREATE TABLE accounts
(
    account_id        serial       NOT NULL PRIMARY KEY,
    company           VARCHAR(128) NOT NULL,
    contact_firstname VARCHAR(128),
    conatact_lastname VARCHAR(128),
    conatct_email     VARCHAR(128),
    conatct_password  VARCHAR(128),
    account_type      VARCHAR(128),
    contact_username  VARCHAR(128),
    support_email     VARCHAR(128) NULL,
    CONSTRAINT uk_company UNIQUE (company)
);

CREATE TABLE app_user_groups
(
    group_id    serial       NOT NULL PRIMARY KEY,
    group_name  VARCHAR(127) NOT NULL,
    description TEXT DEFAULT NULL
);

CREATE TABLE app_users
(
    user_id                  serial              NOT NULL PRIMARY KEY,
    email                    VARCHAR(127) UNIQUE NOT NULL,
    password                 VARCHAR(80)                  DEFAULT NULL,
    firstname                VARCHAR(450)        NOT NULL,
    lastname                 VARCHAR(450)        NOT NULL,
    username                 VARCHAR(130) UNIQUE          default null,
    password_expiration_date TIMESTAMP           NOT NULL DEFAULT '1970-01-02 02:02:02',
    active                   BOOLEAN             NOT NULL,
    locked                   BOOLEAN             NOT NULL,
    last_login               TIMESTAMP           NULL,
    account_id               INT                 NOT NULL,
    UUID                     VARCHAR(50)         NOT NULL,
    encoded                  BOOLEAN             NOT NULL DEFAULT FALSE,
    UAAID                    VARCHAR(50),
    CONSTRAINT uk_uuid UNIQUE (UUID)
);

CREATE TABLE app_user_group_members
(
    id       serial NOT NULL PRIMARY KEY,
    group_id INT    NOT NULL,
    user_id  INT    NOT NULL,
    CONSTRAINT fk_app_user_group_members_group FOREIGN KEY (group_id) REFERENCES app_user_groups (group_id),
    CONSTRAINT fk_app_user_group_members_user FOREIGN KEY (user_id) REFERENCES app_users (user_id)
);

CREATE TYPE statuses AS ENUM ('PENDING','CANCELLED','REJECTED','COMPLETE');

CREATE TABLE outbound_admin_requests
(
    request_id      serial       NOT NULL PRIMARY KEY,
    user_id         INT,
    user_email      VARCHAR(127) NOT NULL,
    user_token      VARCHAR(80)  NOT NULL,
    admin_user_id   INT          NOT NULL,
    request         TEXT         NOT NULL,
    status          statuses     NOT NULL,
    expiration_date TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    CONSTRAINT fk_admin_requests_user_id FOREIGN KEY (user_id) REFERENCES app_users (user_id)
);

CREATE TABLE app_roles
(
    role_sid    serial       NOT NULL PRIMARY KEY,
    name        VARCHAR(127) NOT NULL,
    description TEXT DEFAULT NULL
);

CREATE TABLE app_group_roles
(
    group_id INT    NOT NULL,
    role_sid BIGINT NOT NULL,
    CONSTRAINT fk_app_group_roles_groups FOREIGN KEY (group_id) REFERENCES app_user_groups (group_id),
    CONSTRAINT fk_app_group_roles_roles FOREIGN KEY (role_sid) REFERENCES app_roles (role_sid)
);

CREATE TABLE app_admin_groups
(
    group_id      INT NOT NULL,
    admin_user_id INT NOT NULL,
    CONSTRAINT fk_managed_group FOREIGN KEY (group_id) REFERENCES app_user_groups (group_id),
    CONSTRAINT fk_admin_groups_user FOREIGN KEY (admin_user_id) REFERENCES app_users (user_id)
);

CREATE TABLE app_admin_users
(
    user_id       INT NOT NULL,
    admin_user_id INT NOT NULL,
    CONSTRAINT fk_managed_user FOREIGN KEY (user_id) REFERENCES app_users (user_id),
    CONSTRAINT fk_admin_users_user FOREIGN KEY (admin_user_id) REFERENCES app_users (user_id)
);

CREATE TABLE app_admin_apps
(
    app_id        INT NOT NULL,
    admin_user_id INT NOT NULL,
    CONSTRAINT uk_admin_apps_index UNIQUE (app_id, admin_user_id),
    CONSTRAINT fk_admin_apps_admin_user FOREIGN KEY (admin_user_id) REFERENCES app_users (user_id)
);

CREATE TABLE flow_access
(
    id      INT NOT NULL,
    version INT NOT NULL,
    app_id  INT DEFAULT NULL
);

CREATE TABLE table_access
(
    id      INT NOT NULL,
    version INT NOT NULL,
    app_id  INT DEFAULT NULL
);

CREATE TABLE app_permissions
(
    app_id          INT NOT NULL,
    principal_id    INT     DEFAULT NULL,
    group_principal BOOLEAN DEFAULT FALSE,
    CONSTRAINT uq_app_user_id UNIQUE (app_id, principal_id, group_principal)
);

CREATE TABLE password_change_requests
(
    id        VARCHAR(150) UNIQUE NOT NULL,
    time      TIMESTAMP           NOT NULL,
    user_name VARCHAR(50)         NOT NULL,
    PRIMARY KEY (id)
);

CREATE TABLE m2m_aggregation_filter
(
    account_id    int NOT NULL,
    data_channel  varchar(45) DEFAULT NULL,
    metric        varchar(45) DEFAULT NULL,
    creation_date TIMESTAMP   DEFAULT CURRENT_TIMESTAMP
);
