SET SEARCH_PATH = iqp_apprealm;

-- add new "verb" column to the rest_datasource_api table (to indicate REST method: Get,Post, Put, Delete) 
ALTER TABLE rest_datasource_api
        ADD COLUMN verb TEXT DEFAULT 'get';

-- Set the proper post method verb value (Put, Post, delete) for the existing api's in the table
UPDATE rest_datasource_api
SET verb = 'post'
WHERE id = 9; -- add single tag
UPDATE rest_datasource_api
SET verb = 'post'
WHERE id = 10; -- add bulk tags
UPDATE rest_datasource_api
SET verb = 'put'
WHERE id = 11; -- update tag config
UPDATE rest_datasource_api
SET verb = 'delete'
WHERE id = 13; -- delete tag
UPDATE rest_datasource_api
SET verb = 'put'
WHERE id = 14; -- query results (sets max samples)
UPDATE rest_datasource_api
SET verb = 'put'
WHERE id = 15; -- tag rename
UPDATE rest_datasource_api
SET verb = 'post'
WHERE id = 16;
-- write tag

-- add new row for the POST version of Raw data - copy from the existing GET version
INSERT INTO rest_datasource_api (id, datasource_type, name, url, entity_table_id, verb)
SELECT 17, datasource_type, name, url, entity_table_id, 'post'
FROM rest_datasource_api
WHERE id = 3;
-- Raw

-- add new row for the POST version of interpolated - copy from the existing GET version
INSERT INTO rest_datasource_api (id, datasource_type, name, url, entity_table_id, verb)
SELECT 18, datasource_type, name, url, entity_table_id, 'post'
FROM rest_datasource_api
WHERE id = 4;
-- Interpolated

-- add new row for the POST version of Current Value - copy from the existing GET version
INSERT INTO rest_datasource_api (id, datasource_type, name, url, entity_table_id, verb)
SELECT 19, datasource_type, name, url, entity_table_id, 'post'
FROM rest_datasource_api
WHERE id = 5;
-- current vlaue

-- add new row for the POST version of Calculated Data - copy from the existing GET version
INSERT INTO rest_datasource_api (id, datasource_type, name, url, entity_table_id, verb)
SELECT 20, datasource_type, name, url, entity_table_id, 'post'
FROM rest_datasource_api
WHERE id = 6;
-- calculated

-- add new row for the POST version of Sampled Data - copy from the existing GET version
INSERT INTO rest_datasource_api (id, datasource_type, name, url, entity_table_id, verb)
SELECT 21, datasource_type, name, url, entity_table_id, 'post'
FROM rest_datasource_api
WHERE id = 7;
-- sampled

-- add new row for the POST version of Trend Data - copy from the existing GET version
INSERT INTO rest_datasource_api (id, datasource_type, name, url, entity_table_id, verb)
SELECT 22, datasource_type, name, url, entity_table_id, 'post'
FROM rest_datasource_api
WHERE id = 8;
-- trend

-- add new row for the POST version of Tag Properties - copy from the existing GET version
INSERT INTO rest_datasource_api (id, datasource_type, name, url, entity_table_id, verb)
SELECT 23, datasource_type, name, url, entity_table_id, 'post'
FROM rest_datasource_api
WHERE id = 12;
-- tag properties


-- Some POST queries use both body and query parameters.  Add the query parameters

-- query parameters for POST  Raw data - start, end, count, direction
INSERT INTO rest_datasource_api_parameter
VALUES (66, 'query', 'start', '1970-01-01T00:00:00.000Z', 17);
INSERT INTO rest_datasource_api_parameter
VALUES (67, 'query', 'end', '2000-01-01T00:00:00.000Z', 17);
INSERT INTO rest_datasource_api_parameter
VALUES (68, 'query', 'direction', '0', 17);
INSERT INTO rest_datasource_api_parameter
VALUES (69, 'query', 'count', '50', 17);

-- query parameters for POST Interpolated - start, end, count, intervalMS
INSERT INTO rest_datasource_api_parameter
VALUES (70, 'query', 'start', '1970-01-01T00:00:00.000Z', 18);
INSERT INTO rest_datasource_api_parameter
VALUES (71, 'query', 'end', '2000-01-01T00:00:00.000Z', 18);
INSERT INTO rest_datasource_api_parameter
VALUES (72, 'query', 'count', '50', 18);
INSERT INTO rest_datasource_api_parameter
VALUES (73, 'query', 'intervalMs', '50', 18);

-- query parameters for POST calculated - start, end, calculationMode, count, intervalMS
INSERT INTO rest_datasource_api_parameter
VALUES (74, 'query', 'start', '1970-01-01T00:00:00.000Z', 20);
INSERT INTO rest_datasource_api_parameter
VALUES (75, 'query', 'end', '2000-01-01T00:00:00.000Z', 20);
INSERT INTO rest_datasource_api_parameter
VALUES (76, 'query', 'count', '50', 20);
INSERT INTO rest_datasource_api_parameter
VALUES (77, 'query', 'calculationMode', '1', 20);
INSERT INTO rest_datasource_api_parameter
VALUES (78, 'query', 'intervalMs', '50', 20);

-- path parameter for POST Tag Properties - tagName
INSERT INTO rest_datasource_api_parameter
VALUES (79, 'path', 'tagName', '', 23);


-- Add Body payload Parameter for the POST and Put API items

-- "trend data" body payload for post
INSERT INTO rest_datasource_api_parameter
VALUES (80, 'body', 'payload',
        '{"tagNames" : "*", "start" : "1970-01-01T00:00:00.000Z", "end" : "2000-01-01T00:00:00.000Z", "samplingMode" : 1, "calculationMode" : 1, "direction" : 0, "count" : 0, "intervalMS" : 1000}',
        22);

-- "sampled data" body payload for post
INSERT INTO rest_datasource_api_parameter
VALUES (81, 'body', 'payload',
        '{"tagNames" : "*", "start" : "1970-01-01T00:00:00.000Z", "end" : "2000-01-01T00:00:00.000Z", "samplingMode" : 1, "calculationMode" : 1, "direction" : 0, "count" : 0, "intervalMS" : 1000}',
        21);

-- "calculated data" body payload for post
INSERT INTO rest_datasource_api_parameter
VALUES (82, 'body', 'payload', '{"tagNames" : "*"}', 20);

-- "interpolated data" body payload for post
INSERT INTO rest_datasource_api_parameter
VALUES (83, 'body', 'payload', '{"tagNames" : "*"}', 18);

-- "current Value" body payload for post
INSERT INTO rest_datasource_api_parameter
VALUES (84, 'body', 'payload', '{"tagNames" : "*"}', 19);

-- "raw Data" body payload for post
INSERT INTO rest_datasource_api_parameter
VALUES (85, 'body', 'payload', '{"tagNames" : "*"}', 17);

-- "write Tag" body payload for post
INSERT INTO rest_datasource_api_parameter
VALUES (86, 'body', 'payload',
        '{"TagName": "Testt", "samples": [{"TimeStamp" : "2019-09-24T05:00:00.000Z", "Value" : "123", "Quality" : 3}]}',
        16);

-- "Tag Properties" body payload (JSON array of PropertyName and bool (true/false)) for post
INSERT INTO rest_datasource_api_parameter
VALUES (87, 'body', 'payload', '{ "PropertyName1" : 1, "PropertyName2" : 1}', 23);

-- "Add Single Tag"  body payload for post
INSERT INTO rest_datasource_api_parameter
VALUES (88, 'body', 'payload', '{"Name": "SampleTag", "DataType" : 3}', 9);

-- "Add Bulk Tags" body payload for post
INSERT INTO rest_datasource_api_parameter
VALUES (89, 'body', 'payload', '[{"Name" : "SampleTag1", "DataType" : 3}, {"Name" : "SampleTag2", "DataType" : 3}]',
        10);

-- "Update Tag Configuration" body payload for put (JSON array of PropertyName and PropertyValue) 
INSERT INTO rest_datasource_api_parameter
VALUES (90, 'body', 'payload', '{"PropertyName1" : "PropertyValue1", "PropertyName2" : "PropertyValue2"}', 11);

