SET SEARCH_PATH = iqp_apprealm;


CREATE TABLE alert_definitions
(
    alert_id            SERIAL UNIQUE      NOT NULL,
    event_type          varchar(191)       NOT NULL,
    alert_title         varchar(191)       NOT NULL,
    default_activate    BOOLEAN,
    conditions_operator varchar(191)       NOT NULL,
    complex_expression  varchar(300)            DEFAULT NULL,
    alert_created       Timestamp,
    alert_modified      Timestamp,
    modified_by         INT                NULL DEFAULT NULL,
    account_id          int                NOT NULL,
    UUID                VARCHAR(50) UNIQUE NOT NULL
);

CREATE TABLE alert_conditions
(
    id                        serial       NOT NULL,
    alert_id                  INTEGER      NOT NULL REFERENCES alert_definitions (alert_id),
    condition_order           int          NOT NULL,
    condition_uuid            VARCHAR(50)  NOT NULL,
    type                      varchar(191) NOT NULL,
    device_type               varchar(300) DEFAULT NULL,
    device_group              varchar(300) DEFAULT NULL,
    device_unit               varchar(300) DEFAULT NULL,
    is_override_source        BOOLEAN      DEFAULT FALSE,
    entity_uuid               varchar(45)  DEFAULT NULL,
    type_trigger              varchar(45)  DEFAULT NULL,
    field                     varchar(191) NOT NULL,
    operator                  varchar(191) DEFAULT NULL,
    value_source              varchar(191) DEFAULT NULL,
    value_default             varchar(191) DEFAULT NULL,
    value                     varchar(191) DEFAULT NULL,
    is_input_by_user          BOOLEAN      DEFAULT false,
    input_name                varchar(191) DEFAULT NULL,
    window_type               varchar(191) DEFAULT NULL,
    window_size               int          DEFAULT NULL,
    window_units              varchar(191) DEFAULT NULL,
    aggregate_function        varchar(191) DEFAULT NULL,
    aggregation_operator      varchar(191) DEFAULT NULL,
    aggregation_value_source  varchar(191) DEFAULT NULL,
    aggregation_value_default varchar(191) DEFAULT NULL,
    aggregation_value         varchar(191) DEFAULT NULL,
    is_override_all_condition BOOLEAN      DEFAULT false,
    event_uuid                VARCHAR(50)  NOT NULL,
    PRIMARY KEY (id),
    CONSTRAINT uk_alert_prder UNIQUE (alert_id, condition_order)
);

CREATE TABLE alert_actions
(
    id                         serial       NOT NULL,
    alert_id                   INTEGER      NOT NULL REFERENCES alert_definitions (alert_id),
    event_uuid                 VARCHAR(50)  NOT NULL,
    type                       varchar(191) NOT NULL,
    email_uuid                 varchar(45)   DEFAULT NULL,
    recipients                 TEXT          DEFAULT NULL,
    is_override_recipients     BOOLEAN       DEFAULT NULL,
    recipients_input_name      varchar(45)   DEFAULT NULL,
    recipients_queries         TEXT          DEFAULT NULL,
    send_to                    varchar(45)   DEFAULT NULL,
    source                     varchar(1000) DEFAULT NULL,
    query_uuid                 varchar(45)   DEFAULT NULL,
    inputs                     TEXT         NOT NULL,
    always_take_action         BOOLEAN       DEFAULT NULL,
    repeat                     BOOLEAN       DEFAULT NULL,
    cycle                      int          NOT NULL,
    cycle_set_by_user          BOOLEAN       DEFAULT NULL,
    cycle_input_name           varchar(45)   DEFAULT NULL,
    cycle_interval             int          NOT NULL,
    cycle_interval_set_by_user BOOLEAN       DEFAULT NULL,
    cycle_interval_input_name  varchar(45)   DEFAULT NULL,
    "limit"                    varchar(45)   DEFAULT NULL,
    PRIMARY KEY (id)
);

CREATE TABLE alert_instances
(
    instance_id       serial       NOT NULL,
    alert_id          INTEGER      NOT NULL REFERENCES alert_definitions (alert_id),
    actions_inputs    varchar(400) NOT NULL,
    conditions_inputs varchar(400) NOT NULL,
    activate          BOOLEAN,
    instance_created  Timestamp,
    instance_modified Timestamp,
    user_id           int DEFAULT NULL,
    account_id        int          NOT NULL,
    event_uuid        VARCHAR(50)  NOT NULL,
    PRIMARY KEY (instance_id)
);

CREATE TABLE alerts_feeds
(
    feed_id          serial       NOT NULL,
    alert_id         INTEGER      DEFAULT NULL REFERENCES alert_definitions (alert_id),
    instance_id      int          NOT NULL,
    alert_title      varchar(191) NOT NULL,
    feed_created     Timestamp,
    feed_updated     Timestamp,
    assignee         varchar(300) DEFAULT NULL,
    stage            varchar(300) NOT NULL,
    action_taken     varchar(300) DEFAULT NULL,
    last_action_date Timestamp,
    action_result    varchar(300) DEFAULT NULL,
    user_id          int          DEFAULT NULL,
    account_id       int          NOT NULL,
    event_uuid       VARCHAR(50)  NOT NULL
);

CREATE TABLE alert_instance_actions
(
    state             VARCHAR(10),
    action_time       BIGINT,
    alert_instance_id INTEGER,
    action_id         INTEGER
);
CREATE UNIQUE INDEX index_alert_instance_actions
    ON alert_instance_actions (alert_instance_id, action_id);

CREATE TABLE email_templates
(
    template_id      serial        NOT NULL,
    template_name    VARCHAR(191)  NOT NULL,
    template_subject VARCHAR(2000) NOT NULL,
    template_body    TEXT          NOT NULL,
    template_url     VARCHAR(400)  NOT NULL,
    user_id          INT           NULL,
    account_id       INT           NOT NULL,
    modified_by      INT           NULL,
    modified         TIMESTAMP     NULL,
    UUID             VARCHAR(50)   NOT NULL UNIQUE,
    PRIMARY KEY (template_id)
);
