SET SEARCH_PATH = iqp_m2mrealm;

CREATE TABLE supported_device_gateway_1
(
    int_id         SERIAL NOT NULL,
    device_type_id varchar(191) UNIQUE DEFAULT NULL,
    device_type    varchar(191)        DEFAULT NULL,
    description    varchar(191)        DEFAULT NULL,
    manufactor     varchar(191)        DEFAULT NULL,
    product_code   varchar(191)        DEFAULT NULL,
    generic_1      varchar(191)        DEFAULT NULL,
    generic_2      varchar(191)        DEFAULT NULL,
    pull_interval  INT                 DEFAULT 5000,
    is_active      BOOLEAN             DEFAULT FALSE,
    PRIMARY KEY (int_id)
);

CREATE TABLE cloud_users_1
(
    int_id         SERIAL NOT NULL,
    cloud_id       varchar(191) DEFAULT NULL,
    username       varchar(191) DEFAULT NULL,
    password       varchar(191) DEFAULT NULL,
    account        varchar(191) DEFAULT NULL,
    iqp_account_id int    NOT NULL,
    is_active      BOOLEAN      DEFAULT FALSE,
    pull_interval  INT          DEFAULT 5000,
    PRIMARY KEY (int_id)
);

CREATE TABLE device_gateway_1
(
    int_id          SERIAL              NOT NULL,
    cloud_id        varchar(191)        NOT NULL,
    device_type_id  varchar(191) DEFAULT NULL,
    device_id       varchar(191) UNIQUE NOT NULL,
    device_type     varchar(191) DEFAULT NULL,
    unique_address  varchar(191) DEFAULT NULL,
    url             varchar(191) DEFAULT NULL,
    location        varchar(191) DEFAULT NULL,
    altitude        varchar(191) DEFAULT NULL,
    latitude        varchar(191) DEFAULT NULL,
    longitude       varchar(191) DEFAULT NULL,
    latlong         varchar(191) DEFAULT NULL,
    iqp_account_id  varchar(191) DEFAULT NULL,
    device_username varchar(191) DEFAULT NULL,
    device_password varchar(191) DEFAULT NULL,
    pull_interval   INT          DEFAULT 5000,
    firmware_ver    varchar(191) DEFAULT NULL,
    Description     varchar(191) DEFAULT NULL,
    generic_1       varchar(191) DEFAULT NULL,
    generic_2       varchar(191) DEFAULT NULL,
    is_active       BOOLEAN      DEFAULT FALSE,
    PRIMARY KEY (int_id)
);


CREATE TABLE things_nodes_1
(
    int_id            SERIAL              NOT NULL,
    cloud_id          varchar(191)        NOT NULL,
    device_id         varchar(191) DEFAULT NULL,
    sensor_id         varchar(191) UNIQUE NOT NULL,
    sensor_type       varchar(191) DEFAULT NULL,
    address           varchar(191) DEFAULT NULL,
    location          varchar(191) DEFAULT NULL,
    altitude          varchar(191) DEFAULT NULL,
    latitude          varchar(191) DEFAULT NULL,
    longitude         varchar(191) DEFAULT NULL,
    latlong           varchar(191) DEFAULT NULL,
    iqp_account_id    varchar(191)        NOT NULL,
    sensor_username   varchar(191) DEFAULT NULL,
    sensor_password   varchar(191) DEFAULT NULL,
    firmware_ver      varchar(191) DEFAULT NULL,
    Description       varchar(191) DEFAULT NULL,
    generic_1         varchar(191) DEFAULT NULL,
    generic_2         varchar(191) DEFAULT NULL,
    module_type_desc  varchar(191) DEFAULT NULL,
    product_type_desc varchar(191) DEFAULT NULL,
    instance_code     varchar(191) DEFAULT NULL,
    package_code      varchar(191) DEFAULT NULL,
    class_code        varchar(191) DEFAULT NULL,
    is_active         BOOLEAN      DEFAULT FALSE,
    PRIMARY KEY (int_id)
);



CREATE TABLE M2M_groups_1
(
    int_id            SERIAL       NOT NULL,
    group_id          INT UNIQUE   NOT NULL,
    group_name        varchar(191) DEFAULT NULL,
    device_type_id    varchar(191) DEFAULT NULL,
    group_description varchar(191) DEFAULT NULL,
    gateway_sensor_id varchar(191) DEFAULT NULL,
    group_type        VARCHAR(191) NOT NULL,
    generic_1         varchar(191) DEFAULT NULL,
    generic_2         varchar(191) DEFAULT NULL,
    is_active         BOOLEAN      DEFAULT FALSE,
    PRIMARY KEY (int_id)
);


CREATE TABLE M2M_groups_device_thing_1
(
    int_id           SERIAL       NOT NULL,
    group_id         INT          NOT NULL,
    group_name       VARCHAR(191) NOT NULL,
    gateway_thing_id VARCHAR(191) NOT NULL,
    PRIMARY KEY (int_id)
);

CREATE UNIQUE INDEX index_group_id_name_thing ON M2M_groups_device_thing_1 (group_id, group_name, gateway_thing_id);

CREATE TABLE default_metric_value_1
(
    int_id                  SERIAL       NOT NULL,
    device_type             varchar(191) DEFAULT NULL,
    device_group            varchar(191) DEFAULT NULL,
    device_unit             varchar(191) DEFAULT NULL,
    metric                  varchar(191) NOT NULL,
    default_value           varchar(191) NOT NULL,
    default_aggregate_value varchar(191) DEFAULT NULL,
    PRIMARY KEY (int_id)
);

CREATE UNIQUE INDEX index_type_metric on default_metric_value_1 (device_type asc, metric asc);
CREATE UNIQUE INDEX index_group_metric on default_metric_value_1 (device_group asc, metric asc);
CREATE UNIQUE INDEX index_unit_metric on default_metric_value_1 (device_unit asc, metric asc);

CREATE TABLE metrics_device_type_1
(
    int_id      SERIAL       NOT NULL,
    device_type varchar(191) DEFAULT NULL,
    metric      varchar(191) NOT NULL,
    PRIMARY KEY (int_id)
);

CREATE TABLE M2M_data_channel_1
(
    int_id         SERIAL NOT NULL,
    cloud_id       varchar(191) DEFAULT NULL,
    device_id      varchar(191) DEFAULT NULL,
    instance_name  varchar(191) DEFAULT NULL,
    channel        varchar(191) DEFAULT NULL,
    metric         varchar(191) DEFAULT NULL,
    units          varchar(191) DEFAULT NULL,
    data_type      varchar(191) DEFAULT NULL,
    generic_1      varchar(191) DEFAULT NULL,
    iqp_account_id varchar(191) DEFAULT NULL,
    PRIMARY KEY (int_id)
);


CREATE TABLE device_clouds_1
(
    int_id       SERIAL NOT NULL,
    cloud_id     varchar(191) UNIQUE DEFAULT NULL,
    cloud_vendor varchar(191)        DEFAULT NULL,
    logical_name varchar(191)        DEFAULT NULL,
    cloud_url    varchar(191)        DEFAULT NULL,
    PRIMARY KEY (int_id)
);

CREATE TABLE M2M_data_1
(
    int_id          SERIAL NOT NULL,
    cloud_id        varchar(191) DEFAULT NULL,
    device_id       varchar(191) DEFAULT NULL,
    channel         varchar(191) DEFAULT NULL,
    instance_name   varchar(191) DEFAULT NULL,
    metric          varchar(255) DEFAULT NULL,
    data            varchar(255) DEFAULT NULL,
    data_type       varchar(191) DEFAULT NULL,
    description     varchar(191) DEFAULT NULL,
    altitude        varchar(191) DEFAULT NULL,
    latitude        varchar(191) DEFAULT NULL,
    longitude       varchar(191) DEFAULT NULL,
    generic_1       varchar(191) DEFAULT NULL,
    generic_2       varchar(191) DEFAULT NULL,
    timestamp       Timestamp(3),
    cloud_timestamp Timestamp(3),
    iqp_timestamp   Timestamp(3),
    iqp_time        time,
    iqp_account_id  varchar(191) DEFAULT NULL,
    status          varchar(191) DEFAULT NULL,
    reset_flag      BOOLEAN      DEFAULT NULL,
    LatLong         varchar(400) DEFAULT NULL,
    PRIMARY KEY (int_id)

);


CREATE INDEX cloud_index on M2M_data_1 (cloud_id);
CREATE INDEX chann_indx on M2M_data_1 (channel);
CREATE INDEX data_indx on M2M_data_1 (data);
CREATE INDEX iqp_times_indx on M2M_data_1 (iqp_timestamp);
CREATE INDEX metric_indx on M2M_data_1 (metric);
CREATE INDEX device_indx on M2M_data_1 (device_id);
CREATE INDEX instance_index on M2M_data_1 (instance_name);
CREATE INDEX timestamp_index on M2M_data_1 (timestamp);


CREATE TABLE MQTT_group_topic_1
(
    int_id     SERIAL NOT NULL,
    MQTT_group varchar(191) UNIQUE DEFAULT NULL,
    MQTT_topic varchar(191)        DEFAULT NULL,
    PRIMARY KEY (int_id)
);


CREATE TABLE MQTT_device_topic_1
(
    int_id         SERIAL NOT NULL,
    MQTT_device_id varchar(191) UNIQUE DEFAULT NULL,
    MQTT_topic     varchar(191)        DEFAULT NULL,
    PRIMARY KEY (int_id)
);



INSERT into cloud_users_1 (cloud_id, username, password, account, iqp_account_id, is_active, pull_interval)
VALUES ('IQP_default account', 'defaultIQPuser', 'TMHbWOxsdLx9bHgOcFwzylT20TgIMucf', 'iqp', '1', true, 500);

INSERT into supported_device_gateway_1 (device_type_id, device_type, description, manufactor, pull_interval, is_active)
VALUES (3, 'Testing', 'testing', 'test', 500, true);
INSERT into supported_device_gateway_1 (device_type_id, device_type, description, manufactor, pull_interval, is_active)
VALUES (4, 'Testing2', 'testing', 'test', 500, true);


INSERT into metrics_device_type_1 (device_type, metric)
VALUES ('Testing', 'speed');
INSERT into metrics_device_type_1 (device_type, metric)
VALUES ('Testing', 'light');
INSERT into metrics_device_type_1 (device_type, metric)
VALUES ('Testing', 'Temperature');
INSERT into metrics_device_type_1 (device_type, metric)
VALUES ('Testing', 'pressure');
INSERT into metrics_device_type_1 (device_type, metric)
VALUES ('Testing2', 'speed');
INSERT into metrics_device_type_1 (device_type, metric)
VALUES ('Testing2', 'light');
INSERT into metrics_device_type_1 (device_type, metric)
VALUES ('Testing2', 'Temperature');
INSERT into metrics_device_type_1 (device_type, metric)
VALUES ('Testing2', 'pressure');

INSERT into device_gateway_1(cloud_id, device_type_id, device_id, device_type, unique_address, url, location, altitude,
                             latitude, longitude, latlong, iqp_account_id, device_username, device_password,
                             pull_interval, firmware_ver, description, generic_1, generic_2, is_active)
VALUES ('IQP_default account', 3, 'device1Testing', 'Testing', '123', 'Not set', 'Not set', 'Not set', 0, 0, '0,0', '1',
        '-', '-', 300, 'Not set', 'device #1 for testing', 'Not set', 'Not set', true);
INSERT into device_gateway_1(cloud_id, device_type_id, device_id, device_type, unique_address, url, location, altitude,
                             latitude, longitude, latlong, iqp_account_id, device_username, device_password,
                             pull_interval, firmware_ver, description, generic_1, generic_2, is_active)
VALUES ('IQP_default account', 3, 'device2Testing', 'Testing', '123', 'Not set', 'Not set', 'Not set', 0, 0, '0,0', '1',
        '-', '-', 300, 'Not set', 'device #1 for testing', 'Not set', 'Not set', true);
INSERT into device_gateway_1(cloud_id, device_type_id, device_id, device_type, unique_address, url, location, altitude,
                             latitude, longitude, latlong, iqp_account_id, device_username, device_password,
                             pull_interval, firmware_ver, description, generic_1, generic_2, is_active)
VALUES ('IQP_default account', 3, 'device3Testing', 'Testing', '123', 'Not set', 'Not set', 'Not set', 0, 0, '0,0', '1',
        '-', '-', 300, 'Not set', 'device #1 for testing', 'Not set', 'Not set', true);
INSERT into device_gateway_1(cloud_id, device_type_id, device_id, device_type, unique_address, url, location, altitude,
                             latitude, longitude, latlong, iqp_account_id, device_username, device_password,
                             pull_interval, firmware_ver, description, generic_1, generic_2, is_active)
VALUES ('IQP_default account', 4, 'device1Testing2', 'Testing2', '123', 'Not set', 'Not set', 'Not set', 0, 0, '0,0',
        '1', '-', '-', 300, 'Not set', 'device #1 for testing', 'Not set', 'Not set', true);
INSERT into device_gateway_1(cloud_id, device_type_id, device_id, device_type, unique_address, url, location, altitude,
                             latitude, longitude, latlong, iqp_account_id, device_username, device_password,
                             pull_interval, firmware_ver, description, generic_1, generic_2, is_active)
VALUES ('IQP_default account', 4, 'device2Testing2', 'Testing2', '123', 'Not set', 'Not set', 'Not set', 0, 0, '0,0',
        '1', '-', '-', 300, 'Not set', 'device #1 for testing', 'Not set', 'Not set', true);


INSERT into M2M_groups_1 (group_id, group_name, device_type_id, group_type, is_active)
VALUES (1, 'group1Testing', 3, 'gateway', true);
INSERT into M2M_groups_1 (group_id, group_name, device_type_id, group_type, is_active)
VALUES (2, 'group2Testing', 3, 'gateway', true);
INSERT into M2M_groups_1 (group_id, group_name, device_type_id, group_type, is_active)
VALUES (3, 'group1Testing2', 4, 'gateway', true);
INSERT into M2M_groups_1 (group_id, group_name, device_type_id, group_type, is_active)
VALUES (4, 'group2Testing2', 4, 'gateway', true);

insert into M2M_groups_device_thing_1 (group_id, group_name, gateway_thing_id)
values (1, 'group1Testing', 'device1Testing');
insert into M2M_groups_device_thing_1 (group_id, group_name, gateway_thing_id)
values (1, 'group1Testing', 'device2Testing');
insert into M2M_groups_device_thing_1 (group_id, group_name, gateway_thing_id)
values (1, 'group1Testing', 'device3Testing');
insert into M2M_groups_device_thing_1 (group_id, group_name, gateway_thing_id)
values (2, 'group2Testing', 'device1Testing');
insert into M2M_groups_device_thing_1 (group_id, group_name, gateway_thing_id)
values (2, 'group2Testing', 'device2Testing');
insert into M2M_groups_device_thing_1 (group_id, group_name, gateway_thing_id)
values (2, 'group2Testing', 'device3Testing');
insert into M2M_groups_device_thing_1 (group_id, group_name, gateway_thing_id)
values (3, 'group1Testing2', 'device1Testing2');
insert into M2M_groups_device_thing_1 (group_id, group_name, gateway_thing_id)
values (3, 'group1Testing2', 'device2Testing2');
insert into M2M_groups_device_thing_1 (group_id, group_name, gateway_thing_id)
values (4, 'group2Testing2', 'device1Testing2');
insert into M2M_groups_device_thing_1 (group_id, group_name, gateway_thing_id)
values (4, 'group2Testing2', 'device2Testing2');


insert into default_metric_value_1 (device_type, device_group, device_unit, metric, default_value,
                                    default_aggregate_value)
values ('Testing', null, null, 'speed', 30, 30);
insert into default_metric_value_1 (device_type, device_group, device_unit, metric, default_value,
                                    default_aggregate_value)
values ('Testing', null, null, 'Temperature', 30, 30);
insert into default_metric_value_1 (device_type, device_group, device_unit, metric, default_value,
                                    default_aggregate_value)
values ('Testing2', null, null, 'pressure', 30, 30);
insert into default_metric_value_1 (device_type, device_group, device_unit, metric, default_value,
                                    default_aggregate_value)
values (null, 'group1Testing', null, 'speed', 30, 30);
insert into default_metric_value_1 (device_type, device_group, device_unit, metric, default_value,
                                    default_aggregate_value)
values (null, 'group2Testing', null, 'Temperature', 30, 30);
insert into default_metric_value_1 (device_type, device_group, device_unit, metric, default_value,
                                    default_aggregate_value)
values (null, 'group1Testing2', null, 'Temperature', 30, 30);
insert into default_metric_value_1 (device_type, device_group, device_unit, metric, default_value,
                                    default_aggregate_value)
values (null, 'group2Testing2', null, 'pressure', 30, 30);
insert into default_metric_value_1 (device_type, device_group, device_unit, metric, default_value,
                                    default_aggregate_value)
values (null, null, 'device1Testing', 'light', 30, 30);
insert into default_metric_value_1 (device_type, device_group, device_unit, metric, default_value,
                                    default_aggregate_value)
values (null, null, 'device2Testing', 'pressure', 30, 30);
insert into default_metric_value_1 (device_type, device_group, device_unit, metric, default_value,
                                    default_aggregate_value)
values (null, null, 'device1Testing2', 'speed', 30, 30);





	
	
	
	
	
	
	
	
	
	
	
	
