SET SEARCH_PATH = iqp_siterealm;

CREATE TABLE IF NOT EXISTS site_acl_sids
(
    sid       serial NOT NULL PRIMARY KEY,
    principal BOOLEAN
);


CREATE TABLE site_users
(
    user_id                  serial              NOT NULL PRIMARY KEY,
    email                    VARCHAR(127) UNIQUE NOT NULL,
    password                 VARCHAR(127)                 DEFAULT NULL,
    firstname                VARCHAR(127)        NOT NULL,
    lastname                 VARCHAR(127)        NOT NULL,
    username                 VARCHAR(130) UNIQUE          default null,
    password_expiration_date TIMESTAMP           NOT NULL DEFAULT '1970-01-02 02:02:02',
    active                   BOOLEAN             NOT NULL,
    locked                   BOOLEAN             NOT NULL,
    last_login               TIMESTAMP           NULL,
    account_id               INT                 NOT NULL,
    encoded                  BOOLEAN             NOT NULL DEFAULT FALSE,
    UAAID                    VARCHAR(50)
);

CREATE TABLE site_user_groups
(
    group_id    serial              NOT NULL PRIMARY KEY,
    sid         BIGINT              NOT NULL,
    name        VARCHAR(127) UNIQUE NOT NULL,
    description TEXT DEFAULT NULL,
    CONSTRAINT fk_site_user_group_sid FOREIGN KEY (sid) REFERENCES site_acl_sids (sid)
);

CREATE TABLE site_user_group_members
(
    id       serial NOT NULL PRIMARY KEY,
    group_id INT    NOT NULL,
    user_id  INT    NOT NULL,
    CONSTRAINT fk_site_user_group_members_group FOREIGN KEY (group_id) REFERENCES site_user_groups (group_id),
    CONSTRAINT fk_site_user_group_members_user FOREIGN KEY (user_id) REFERENCES site_users (user_id)
);

CREATE TABLE site_authorities
(
    auth_sid    serial              NOT NULL PRIMARY KEY,
    name        VARCHAR(127) UNIQUE NOT NULL,
    description TEXT    DEFAULT NULL,
    base_auth   BOOLEAN DEFAULT FALSE,
    CONSTRAINT fk_site_auth_acl_sid FOREIGN KEY (auth_sid) REFERENCES site_acl_sids (sid)
);

CREATE TABLE site_user_group_authorities
(
    id       serial NOT NULL PRIMARY KEY,
    group_id INT    NOT NULL,
    auth_sid BIGINT NOT NULL,
    CONSTRAINT fk_site_user_group_auth_sid FOREIGN KEY (auth_sid) REFERENCES site_authorities (auth_sid)
);

CREATE TYPE statuses AS ENUM ('PENDING','CANCELLED','REJECTED','COMPLETE');

CREATE TABLE outbound_admin_requests
(
    request_id      serial PRIMARY KEY,
    user_id         INT,
    user_email      VARCHAR(127) NOT NULL,
    user_token      VARCHAR(80)  NOT NULL,
    admin_user_id   INT          NOT NULL,
    request         TEXT         NOT NULL,
    status          statuses     NOT NULL,
    expiration_date TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    CONSTRAINT fk_admin_requests_user_id FOREIGN KEY (user_id) REFERENCES site_users (user_id)
);

CREATE TABLE site_logs
(
    ID         serial PRIMARY KEY,
    APP        VARCHAR(20) NOT NULL,
    USER_ID    VARCHAR(20) NOT NULL,
    ACCOUNT_ID VARCHAR(20) NOT NULL,
    DATED      TIMESTAMP   NOT NULL,
    LOGGER     TEXT        NOT NULL,
    LEVEL      VARCHAR(10) NOT NULL,
    MESSAGE    TEXT DEFAULT NULL
);

CREATE TABLE openids
(
    id         serial              NOT NULL PRIMARY KEY,
    openid_url VARCHAR(255) UNIQUE NOT NULL,
    username   VARCHAR(130)        NOT NULL,
    logout_url VARCHAR(255),
    general    TEXT
);
