Write-Host "########## Welcome to Operations hub Restore Tool ###########" -ForegroundColor gray

#Pre-req
function Check-IsElevated
{
    $id = [System.Security.Principal.WindowsIdentity]::GetCurrent()
    $p = New-Object System.Security.Principal.WindowsPrincipal($id)
    if ($p.IsInRole([System.Security.Principal.WindowsBuiltInRole]::Administrator))
	{ Write-Output $true }
	else
	{ Write-Output $false }  
}
if (-not(Check-IsElevated))
{ 
	throw "Please run this script as an administrator" 
}

$userConsent=Read-host "The Restore operation will delete everything from the current system. We advice you to take a backup of current system and then perform restore. Do you want to continue with restore? (Yes|No)"
if ($userConsent -eq "No") {
	exit
}

#1. Extract the backup zip
Write-Progress -Activity "Starting Backup Archive extraction" -Status "Progress:" -PercentComplete (0/7*100) 
$zipFileAbsolutePath = $args[0]
#$zipFileAbsolutePath = "C:\ProgramData\OPERATIONS_HUB_BKP_20210921-171152.zip"
if($zipFileAbsolutePath -eq $null)
{
	throw 'Script require a param <PATH_TO_BACKUP_ARCHIVE>'
	
}
if(-Not(Test-Path -Path $zipFileAbsolutePath -PathType Leaf))
{
	throw "$zipFileAbsolutePath is not a valid file"
}
$zipFileName = Get-ChildItem $zipFileAbsolutePath
$bkpFolderName = $zipFileName.BaseName

$iqpTomcatLogPath = Get-ItemPropertyValue 'HKLM:\SOFTWARE\GE\Operations Hub\IQP Tomcat Server' -Name LogPath
$programDataDir = "$iqpTomcatLogPath\..\.."

$extractedbbkpfolder = "$programDataDir\$bkpFolderName"
new-item $extractedbbkpfolder -itemtype directory

Expand-Archive -LiteralPath $zipFileAbsolutePath -DestinationPath $extractedbbkpfolder

Write-Host "1. SQL Dump archive has been extracted."
Write-Progress -Activity "Backup Archive extraction completed" -Status "Progress:" -PercentComplete (1/7*100)

#1.1 Validate presence of files
if(((Test-Path -Path "$extractedbbkpfolder\webhmi-postgres\WebHMI-Dump.sql","$extractedbbkpfolder\iqp-postgres\IQP-Dump.sql","$extractedbbkpfolder\uaa-postgres\UAA-Dump.sql","$extractedbbkpfolder\EnvironmentVars.txt" -PathType Leaf) -eq $false).Count)
{
	Remove-Item -Path $extractedbbkpfolder -recurse
	Write-Host "FATAL : The archive has missing items or is corrupted. Please check." -ForegroundColor red
	exit
}

#2.Stop master service
Write-Progress -Activity "Stopping Operations Hub Services" -Status "Progress:" -PercentComplete (1/7*100) 

$MasterService = Get-Service -Name "GeOphubMasterStarter" 

if ($MasterService.Status -ne "Running"){
	Write-Host "2. GeOphubMasterStarter is already stopped"
}
if ($MasterService.Status -eq "Running"){ 
	Stop-Service -Name $MasterService.Name
	while ( (get-service -Name "UaaTomcat").Status -ne "Stopped" -and (get-service -Name "IqpTomcat").Status -ne "Stopped" -and (get-service -Name "WebhmiTomcat").Status -ne "Stopped") {
        Start-Sleep -Seconds 10
    }
	Write-Host "2. GeOphubMasterStarter service has been stopped"
	Start-Sleep -Seconds 240
}

Write-Progress -Activity "Stopped Operations Hub Services" -Status "Progress:" -PercentComplete (2/7*100)

#3.Get Current user entry as admin in postgreSQL identity



#4.Execute Restore commands

#4.1 Replace IQP Config Path in DB if found
$newiqpconfigPath = Get-ItemPropertyValue 'HKLM:\SOFTWARE\GE\Operations Hub\IQP Configuration' -Name IQPConfigPath
$newiqpconfigPath = $newiqpconfigPath.replace('\','\\')

$env_vars = Get-Content "$extractedbbkpfolder\EnvironmentVars.txt"
Foreach ($entry in $env_vars)
{
	if($entry.contains("IQPConfigPath"))
	{
		$oldiqpconfigPath = $entry.split("=")[1]
		$oldiqpconfigPath = $oldiqpconfigPath.replace('\','\\')
	}
}
if (-Not($oldiqpconfigPath -eq $null) -and (Select-String -Path $extractedbbkpfolder\iqp-postgres\IQP-Dump.sql -Pattern $oldiqpconfigPath -SimpleMatch -Quiet) -and ($newiqpconfigPath -ne $oldiqpconfigPath)) {
    $iqpDump = Get-Content $extractedbbkpfolder\iqp-postgres\IQP-Dump.sql -Encoding default
    $iqpDump = $iqpDump.replace($oldiqpconfigPath, $newiqpconfigPath)
	$iqpDump | out-file $extractedbbkpfolder\iqp-postgres\IQP-Dump.sql -Encoding default
    Write-Host "3.1 Few instances of File Paths found in DB which has changed now. Those are fixed now."
}

#4.2 Restoring the DB
$iqpPostgresPort = Get-ItemPropertyValue 'HKLM:\SOFTWARE\GE\Operations Hub\IQP Postgres Server' -Name Port 
$uaaPostgresPort = Get-ItemPropertyValue 'HKLM:\SOFTWARE\GE\Operations Hub\UAA Postgres Server' -Name Port
$webhmiPostgresPort = Get-ItemPropertyValue 'HKLM:\SOFTWARE\GE\Operations Hub\WebHMI Postgres Server' -Name Port 

$binDirectory = Get-ItemPropertyValue 'HKLM:\SOFTWARE\GE\Operations Hub\Postgres Binaries*' -Name binPath
if (-Not(Test-Path -Path $binDirectory)) {
    throw "$binDirectory is not a valid folder"
}
#cmd.exe /c "$binDirectory\bin\psql.exe" -f "$extractedbbkpfolder\webhmi-postgres\WebHMI-Dump.sql" -U postgres -h localhost -p 9434 | Out-File -FilePath "$extractedbbkpfolder\webhmi-postgres\restore.log"
#cmd.exe /c "$binDirectory\bin\psql.exe" -f "$extractedbbkpfolder\iqp-postgres\IQP-Dump.sql" -U postgres -h localhost -p 5432 | Out-File -FilePath "$extractedbbkpfolder\iqp-postgres\restore.log"
#cmd.exe /c "$binDirectory\bin\psql.exe" -f "$extractedbbkpfolder\uaa-postgres\UAA-Dump.sql" -U postgres -h localhost -p 9432 | Out-File -FilePath "$extractedbbkpfolder\uaa-postgres\restore.log"

Start-Process -FilePath "$binDirectory\psql.exe" -ArgumentList "-U postgres -h localhost -p $webhmiPostgresPort -f $extractedbbkpfolder\webhmi-postgres\WebHMI-Dump.sql" -Wait -WindowStyle Maximized
Start-Process -FilePath "$binDirectory\psql.exe" -ArgumentList "-U postgres -h localhost -p $iqpPostgresPort -f $extractedbbkpfolder\iqp-postgres\IQP-Dump.sql" -Wait -WindowStyle Maximized
Start-Process -FilePath "$binDirectory\psql.exe" -ArgumentList "-U postgres -h localhost -p $uaaPostgresPort -f $extractedbbkpfolder\uaa-postgres\UAA-Dump.sql" -Wait -WindowStyle Maximized
Write-Host "3. Database restore completed for IQP, UAA and WebHMI."
Write-Progress -Activity "Database restore completed for IQP, UAA and WEBHMI" -Status "Progress:" -PercentComplete (3/7*100)

#4.3 Restore filesystem
if(Test-Path -Path "$extractedbbkpfolder\images") 
{
	Copy-Item -Path "$extractedbbkpfolder\images\*" -Destination "$programDataDir\GE\Operations Hub\iqp-config\iqpsites\iqp\imagedata" -Recurse -Container
}
$endappProgramFiles = Get-ItemPropertyValue 'HKLM:\SOFTWARE\GE\Operations Hub\IQP Endapp' -Name IQPEndappPath
if(Test-Path -Path "$extractedbbkpfolder\plugins")
{
	$sourcePluginDirs = Get-ChildItem -Path "$extractedbbkpfolder\plugins" -Directory
	$targetPluginParentDir = "$endappProgramFiles\public\custom\default"
	Foreach($sourcePluginDir in $sourcePluginDirs)
	{
		$pluginName = $sourcePluginDir.BaseName
		if(Test-Path -Path "$targetPluginParentDir\$pluginName")
		{
			continue
		}
		else
		{
			$sourceDir = $sourcePluginDir.FullName
			new-item $targetPluginParentDir\$pluginName -itemtype directory
			Copy-Item -Path "$sourceDir\*" -Destination "$targetPluginParentDir\$pluginName" -Recurse
		}
	}
}
Write-Host "4. Filesystem restore completed for Images and plugins."
Write-Progress -Activity "Filesystme restore completed for Images and plugins" -Status "Progress:" -PercentComplete (4/7*100)

#5. Restore the Environment variables
#5.1 Read the backup environment files
$env_vars = Get-Content "$extractedbbkpfolder\EnvironmentVars.txt"
Foreach ($entry in $env_vars)
{
	if($entry.contains("UAA_CLIENT_SECRET"))
	{
		$iqpUAAClientSecret = $entry
	}
	elseif($entry.contains("DB_ENCRYPTKEY"))
	{
		$iqpDBEncryptKey = $entry
	}
	elseif($entry.contains("-Dwebhmi.security.oauth2.client.client-secret"))
	{
		$webhmiUAAClientSecret = $entry
	}
	elseif($entry.contains("EncKey"))
	{
		$iqpEncryptKey = $entry
	}
	elseif($entry.contains("SourceFQDNName"))
	{
		$sourcefqdnName = $entry.split("=")[1]
	}
}
Write-Progress -Activity "Environment variables read from backup completed" -Status "Progress:" -PercentComplete (5/7*100)

#5.2 Replace the properties in registry from backup file
$iqpenvironmentValues = Get-ItemPropertyValue 'HKLM:\SOFTWARE\WOW6432Node\Apache Software Foundation\Procrun 2.0\IqpTomcat\Parameters' -Name Environment
[bool] $isIqpdbEncryptKeyEntryMade = $false
for ($i=0; $i -lt $iqpenvironmentValues.length; $i++) {
	if($iqpenvironmentValues[$i].contains("UAA_CLIENT_SECRET"))
	{
		$iqpenvironmentValues[$i] = $iqpUAAClientSecret
	}
	elseif($iqpenvironmentValues[$i].contains("DB_ENCRYPTKEY"))
	{
		$iqpenvironmentValues[$i] = $iqpDBEncryptKey
		$isIqpdbEncryptKeyEntryMade = $true
	}
	elseif($iqpenvironmentValues[$i].contains("OPHUB_POSTGRES_PASSWORD"))
	{
		$ophubpostgresPassword = $iqpenvironmentValues[$i].split("=")[1]
	}
	elseif($iqpenvironmentValues[$i].contains("DOMAIN"))
	{
		$targetfqdnName = $iqpenvironmentValues[$i].split("=")[1].split(",")[0]
	}
}
if(-Not($iqpDBEncryptKey -eq $null) -and -Not $isIqpdbEncryptKeyEntryMade)
{
	$iqpenvironmentValues += $iqpDBEncryptKey
}

Set-ItemProperty -Path 'HKLM:\SOFTWARE\WOW6432Node\Apache Software Foundation\Procrun 2.0\IqpTomcat\Parameters' -Name Environment -Value $iqpenvironmentValues

$webhmiJavaValues = Get-ItemPropertyValue 'HKLM:\SOFTWARE\WOW6432Node\Apache Software Foundation\Procrun 2.0\WebhmiTomcat\Parameters\Java' -Name Options
for ($i=0; $i -lt $webhmiJavaValues.length; $i++) {
	if($webhmiJavaValues[$i].contains("-Dwebhmi.security.oauth2.client.client-secret"))
	{
		$webhmiJavaValues[$i] = $webhmiUAAClientSecret
	}
}

Set-ItemProperty -Path 'HKLM:\SOFTWARE\WOW6432Node\Apache Software Foundation\Procrun 2.0\WebhmiTomcat\Parameters\Java' -Name Options -Value $webhmiJavaValues

$webhmienvironmentValues = Get-ItemPropertyValue 'HKLM:\SOFTWARE\WOW6432Node\Apache Software Foundation\Procrun 2.0\WebhmiTomcat\Parameters' -Name Environment
for ($i=0; $i -lt $webhmienvironmentValues.length; $i++) {
	if($webhmienvironmentValues[$i].contains("POSTGRES_PASSWORD"))
	{
		$webhmiPostgrespassword = $webhmienvironmentValues[$i].split("=")[1]
	}
}

#5.3 Execute IQP DB update for images for FQDN change
$sqlQuery = "UPDATE iqp_apprealm.pages SET components = REPLACE(components,'$sourcefqdnName','$targetfqdnName');";
Start-Process -FilePath "$binDirectory\psql.exe" -ArgumentList "-U postgres -h localhost -p $iqpPostgresPort -d opcenter", "`"-c $sqlQuery`"" -Wait -WindowStyle Maximized

Set-ItemProperty -Path 'HKLM:\SOFTWARE\GE\Operations Hub\IqpDb' -Name EncKey -Value $iqpEncryptKey.split('=')[1]
Write-Host "5. Environment variables are restored from Archive."

#6. DB-Initializer execution
$jreDirectory = Get-ItemPropertyValue 'HKLM:\SOFTWARE\GE\Operations Hub\Java Runtime by AdoptOpenJdk' -Name JavaHome
$ophubInstallDir = "$jreDirectory\.."

$ophubProgramDataDir = "$programDataDir\GE\Operations Hub"
$dbInitializerPath = "$ophubInstallDir\iqp-tomcat\webapps\site\WEB-INF\db-initializer.jar"
$postgresPropsPath = "$ophubProgramDataDir\iqp-config\IQP\site\postgres-jdbc.properties"

#cmd.exe /c "cd /D `"$ophubInstallDir\webhmi-tomcat\webapps\server-detail-microservice-impl\sql`"&& SET PGHOST=localhost&& SET PGPASSWORD=$webhmiPostgrespassword&& SET PGDATABASE=postgres&& `"$ophubInstallDir\webhmi-tomcat\webapps\server-detail-microservice-impl\sql\CreateDatabase.Bat`" -SU postgres -po $webhmiPostgresPort -d serverdetail -u serverdetail_user -p $webhmiPostgrespassword -psql `"$binDirectory\psql.exe`""

Start-Process -FilePath "C:\Windows\System32\cmd.exe" -ArgumentList "/c cd /D `"$ophubInstallDir\webhmi-tomcat\webapps\server-detail-microservice-impl\sql`"&& SET PGHOST=localhost&& SET PGPASSWORD=$webhmiPostgrespassword&& SET PGDATABASE=postgres&& `"$ophubInstallDir\webhmi-tomcat\webapps\server-detail-microservice-impl\sql\CreateDatabase.Bat`" -SU postgres -po $webhmiPostgresPort -d serverdetail -u serverdetail_user -p $webhmiPostgrespassword -psql `"$binDirectory\psql.exe`"" -Wait -WindowStyle Maximized

Write-Host "5.1 ServerDetail Schema Change done in v2.0 validated"

if(Test-Path -Path $dbInitializerPath -PathType Leaf)
{
	Start-Process -FilePath "$jreDirectory\bin\java.exe" -ArgumentList "`"-Dpostgres.jdbc.properties=$postgresPropsPath`"", "-DOPHUB_POSTGRES_PASSWORD=$ophubpostgresPassword", "-jar `"$dbInitializerPath`"" -Wait -WindowStyle Maximized
	
	Write-Host "6. The DDL/DML is executed based on version of data from Operations Hub"
} else {
	Write-Host "6. The DB-Initializer file is not found at $dbInitializerPath"
}
Write-Progress -Activity "DB-Initializer execution completed" -Status "Progress:" -PercentComplete (6/7*100)


#7. Start master service
Start-Service -Name "GeOphubMasterStarter"
Remove-Item -Path $extractedbbkpfolder -recurse
Write-Host "7. The master service has been started back. The services will take around 5mins to gracefully start."

Write-Progress -Activity "Environment variables restore activity completed" -Status "Progress:" -PercentComplete (7/7*100)
Write-Host "Your restore of Operations Hub completed successfully from $zipFileAbsolutePath."